{% extends "base.html" %}
{% block content %}

<style>
  .content  {
      padding-top:150px;
  }

  .envelope {
      position: relative;
      margin: 50px auto 0;
      width: 400px;
      height: 200px;
      background: #00528c;
      border-radius: 0 0 5px 5px;
      box-shadow: 0 0 1px #c94548 inset;
  }
  
  .envelope:before,
  .envelope:after {
      content: '';
      position: absolute;
      width: 0;
      height: 0;
      border: 0 solid transparent;
      border-width: 100px 200px;
  }
  .envelope:before {
      border-bottom-color: #255e87;
      top: -100%;
      left: 0px;
  }
  .envelope:after {
      border-right-color: #b3d7ff;
      border-left-color:  #97b3d3;
      border-bottom-color:#b3d7e0;
      top: 0;
      border-radius: 0 0 5px 5px;
      transform: rotate(360deg);
      box-shadow: 0 1px 1px rgba(0,0,0,0.25);
      z-index:3;
  }
  
  .triangle  {
      border-style:solid;      
      border-width: 150px 300px;
      position: absolute;
      z-index:3;
  }
  
  .triangle-down {
      border-color: #00528c transparent transparent transparent;
      z-index:1;      
  }


  .rect {
      left: 5%;
      bottom:0;
      border-radius:6px;
      width: 90%;
      height:200px;
      background: white;
      display: inline-block;
      border-style:solid;
      border-color:#b3d7ff;
      box-shadow: inset -3px 3px 10px #b3d7ff;
      position:absolute;
      padding-bottom:30px;
  }
  .recto {
      position:relative;
      width: 100%;
      height: 700px;
      background: white;
      display: inline-block;
      z-index:20;
  }
  .go-up {
      animation-delay:0.6s;
      animation-name: go-up;
      animation-duration: 2s;
      animation-fill-mode: forwards;
  }

  .scale-up {
      animation-delay:0.6s;
      animation-name: scale-up;
      animation-duration: 2s;
      animation-fill-mode: forwards;
  }
  

  .go-behind {
      animation-delay:1s;
      animation-name: go-behind;
      animation-duration: 1s;
      animation-fill-mode: forwards;
  }

  .open
  {
      animation-name: open;
      animation-duration: 2s;
      animation-fill-mode: forwards;
      transform-origin: top;
  }

  .boldos
  {
      color:#007bff;
      font-size:1.2rem;
      font-weight:bold;
  }
  
  .envelopeso
  {
      position:relative;
      margin-top:500px;
      text-align: center;
      width:400px;
      height:500px;
  }

  .begin {
      position:relative;
      bottom: 160px;
      left: 45%;
      z-index:5;
      transition: 0.3s;
      animation: fadein 2s;
      animation-delay:1.6s;
      opacity: 0;
      animation-fill-mode: forwards;      
  }

  @keyframes fadein {
      from { opacity: 0; }
      to { opacity: 1; }      
  }
  
  @keyframes go-up {
      0% { bottom:0px;}
      100% { bottom:100px;
	     z-index:1;}
  }


  @keyframes open {
      from { transform: scaleY(1);}
      to { transform: scaleY(-1);z-index:0}
  }

  h1 {
      font-size:1rem;
  }
  h2 {
      font-size:0.7rem;
  }
  p {
      font-size:0.8rem;
  }
  

</style>


<div class="envelope">
  <div class="rect go-up" style="display: inline-block">
    <div style="display: inline-block;position:relative">
      <div class="col-lg-12 text-center mt-3" style="position:relative; text-align:center;">
        <p style="margin-bottom:0">
          So you are looking for best
          <br>
          <span class="boldos"> Email Marketing Service
	  </span>?
        </p>
        <div style="width:80%; padding-left:20%;">
          <p style="margin-bottom:.1rem;color:#4c85c2;">
            Please, answer few questions.
          </p>
          <p>
            When you'll be ready hit button "No more questions. ANSWERS!"
          </p>
        </div>
      </div>
    </div>
  </div>
</div>
<form method="post" class="begin">
  <button type="submit" style="z-index:6;" class="btn btn-primary">Begin</button>
</form>


{% endblock %}
