{% extends "base.html" %}

{% block content %}
<header class="masthead" style="background-image: url({{post.coverImage.url}})">
  <div class="overlay"></div>
  <div class="container">
    <div class="row">
      <div class="col-lg-8 col-md-10 mx-auto">
        <div class="post-heading position-relative">
          <h1>{% block title %}{{ post.title }}{% endblock %}</h1>
        </div>
      </div>
    </div>
  </div>
</header>

<article>
  <div class="container">
    <div class="row">
      <div class="col-lg-8 col-md-10 mx-auto post-content">
        {{post.contentInMarkdown | markdown}}
      </div>
    </div>
  </div>
</article>
{% endblock %}
